#!/usr/bin/python
# -*- coding: utf-8 -*-
PYTHONIOENCODING="UTF-8"

'''*
	Copyright (C) 2016 DudeHere

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.

*'''

import os
import re
import sys
import xbmc
import json
from dudehere.routines import *
from dudehere.routines.plugin import Plugin
from dudehere.routines.vfs import VFSClass
from dudehere.routines.window import Window
plugin =  Plugin()
vfs = VFSClass()
def first_run():
	pass
plugin.first_run = first_run
if ADDON.get_bool_setting('movie_custom_directory'):
	MOVIE_DIRECTORY = ADDON.get_setting('movie_directory')
else:
	MOVIE_DIRECTORY = "special://userdata/addon_data/%s/movies" % ADDON_ID

if ADDON.get_bool_setting('tv_show_custom_directory'):
	TVSHOW_DIRECTORY = ADDON.get_setting('tv_show_directory')
else:
	TVSHOW_DIRECTORY = "special://userdata/addon_data/%s/tvshows" % ADDON_ID
TVSHOW_DIRECTORY = 'smb://fins.buffett/kodi/walter/tvshows'

def is_strm_path(path):
	if path.startswith(TVSHOW_DIRECTORY) or path.startswith(MOVIE_DIRECTORY):
		return True
	seasons = vfs.ls(path)
	for season in seasons[0]:
		test = vfs.ls( vfs.join(path, season), pattern='strm$')
		if len(test[1]) > 0: return True
	
	return False
		
def main():
	if ADDON.get_setting('trakt_authorized') == 'false':
		xbmc.executebuiltin('RunScript(service.walter.sobchak,mode=authorize_trakt)')
		if ADDON.get_setting('trakt_authorized') == 'false': return
		
	path = xbmc.getInfoLabel('ListItem.FileNameAndPath')
	if not path:
		path = xbmc.getInfoLabel('ListItem.Path')

	is_strm =  is_strm_path(path)
	is_pvr = False if xbmc.getInfoLabel('ListItem.ChannelName') == '' else True
	short_list = True if xbmc.getInfoLabel('ListItem.IMDBNumber') == '' else False
	title = xbmc.getInfoLabel('ListItem.Title')
	title = re.sub(' \(\d{4}\)$', '', title)
	
	if short_list:
		items = ["Update Walter", "List Manager"]
		height = 167
	
	elif is_strm:
		items = ["Update Walter", "Remove from List", "Delete from Library", "List Manager"]
		height = 270
	else:
		items = ["Update Walter", "Add to list", "List Manager"]
		height = 215
	
	class ContextWindow(Window):
		_action = 'false'
		def __init__(self, title):
			super(self.__class__,self).__init__(title,width=300, height=height, columns=1, rows=4, quiet=True)
			
		def event(self):
			obj = self.getFocus()
			self._action = obj.getSelectedPosition()
			self.close()
		
		def set_info_controls(self):
			self.create_list('dialog')
			self.add_object('dialog', 0,0,5,1)
			self.add_list_items('dialog', items, selectable=False, call_back=self.event)
			for item in items:
				index = items.index(item)
				icon = item.replace(" ", "_").lower()
				icon = vfs.join(ARTWORK, icon + '.png')
				self.get_object('dialog').getListItem(index).setIconImage(icon)
			self.set_object_event('focus', 'dialog')
	CW = ContextWindow("Walter Sobchak")
	CW.show()
	action = CW._action
	del CW
	
	if action != "false":
		action = items[action]
		media = 'shows' if xbmc.getInfoLabel('ListItem.DBTYPE') == 'tvshow' else 'movie'
		year = xbmc.getInfoLabel('ListItem.Year')	
		id = xbmc.getInfoLabel('ListItem.IMDBNumber')
		db_id = xbmc.getInfoLabel('ListItem.DBID')

		if action == 'Remove from List':
			ok = plugin.confirm('Remove from list?', "click YES to continue", title)
			if ok:
				from dudehere.routines.trakt import TraktAPI
				trakt = TraktAPI()
				lists = trakt.get_custom_lists()
				if lists:
					for list in lists:
						response = trakt.delete_from_custom_list(media, list['ids']['slug'], id, id_type = 'tvdb' if media == 'shows' else 'imdb')
					plugin.notify('Success', 'Removed: %s' % title, image=ARTWORK + 'trakt.png')
				else:
					plugin.notify('Error', 'No lists found', image=ARTWORK + 'trakt.png')
		elif action == "Delete from Library":
			ok = plugin.confirm('Delete from library?', "click YES to continue", title)
			if ok:
				from dudehere.routines.trakt import TraktAPI
				trakt = TraktAPI()
				lists = trakt.get_custom_lists()
				if lists:
					for list in lists:
						response = trakt.delete_from_custom_list(media, list['ids']['slug'], id, id_type = 'tvdb' if media == 'shows' else 'imdb')
				vfs.rm(path, recursive=True)
				if media == 'shows':
					cmd = '{"jsonrpc": "2.0", "method": "VideoLibrary.RemoveTVShow", "params": {"tvshowid": %s}, "id": "libTvShows"}' % db_id
				else:
					cmd = '{"jsonrpc": "2.0", "method": "VideoLibrary.RemoveMovie", "params": {"movieid": %s}, "id": "libMovies"}' % db_id
				response = json.loads(xbmc.executeJSONRPC(cmd))
				ADDON.log( response )
				plugin.notify('Success', 'Deleted: %s' % title, image=ARTWORK + 'walter.png')
		elif action == 'Update Walter':
			if media == 'shows':
				xbmc.executebuiltin('RunScript(service.walter.sobchak,mode=update_tvshows)')
			else:
				xbmc.executebuiltin('RunScript(service.walter.sobchak,mode=update_movies)')
		elif action == 'Add to list':
			from dudehere.routines.trakt import TraktAPI
			trakt = TraktAPI()
			lists = trakt.get_custom_lists()
			if not lists:
				plugin.notify('Error', 'No lists found', image=ARTWORK + 'trakt.png')
				return
			options = [lists[index]['name'] for index in xrange(len(lists))]
			index = plugin.dialog_select('Add to List', options)
			if index:
				slug = lists[index]['ids']['slug']
				id_type = 'tvdb' if media == 'shows' else 'imdb'
				response = trakt.add_to_custom_list(media, slug, id, id_type)
				if response['added'][media]==1:
					plugin.notify('Success', 'Added to custom List', image=ARTWORK + 'trakt.png')
				elif response['existing'][media]==1:
					plugin.notify('Error', 'Already exists in list', image=ARTWORK + 'trakt.png')
				else:
					plugin.notify('Failed', 'Please check your log for details', image=ARTWORK + 'trakt.png')
		elif action == 'List Manager':
			print "blah"
			xbmc.executebuiltin('RunScript(service.walter.sobchak,mode=main)')

plugin.register('main', main)

if __name__ == '__main__':
	plugin.run()